WS1 - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# WS1

The WS1 stations produce data every 1/2 second or so.

## Configuring with `weectl device`

The WS1 stations cannot be configured with the utility `weectl device`.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

WS1 station data
Database Field | Observation | Loop | Archive
barometer |  | S |
pressure | pressure | H |
altimeter |  | S |
inTemp | temperature_in | H |
outTemp | temperature_out | H |
inHumidity | humidity_in | H |
outHumidity | humidity_out | H |
windSpeed | wind_speed | H |
windDir | wind_dir | H |
rain | rain | D |
| rain_total | H |
rainRate |  | S |
dewpoint |  | S |
windchill |  | S |
heatindex |  | S |

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service